from loguru import logger


# context
#   boxes: structure of boxes
#   client: MQTT client
#
# boxes['box_name']['context']
#   store here what ever is require to represent the state of the box

def process_message(box_name, topic_key, payload, context):
    logger.info(f"{context=}")
    try:
        logger.info(f"[{box_name}] Processing message for '{topic_key}': {payload}")

        match topic_key.split('/'):
            case [ primary_key, sub_key ] if primary_key == 'window':
                result = process_window(box_name, context, sub_key, payload)
            case [ primary_key ] if primary_key == 'high_temp':
                result = process_high_temp(box_name, context, payload)
            case [ primary_key ] if primary_key == 'cmd':
                result = process_cmd(box_name, context, payload)
            case [ primary_key ] if primary_key == 'general_off':
                result = process_general_off(box_name, context, payload)
            case [ primary_key ] if primary_key == 'maintenance_mode':
                result = process_maintenance_mode(box_name, context, payload)
            case _:
                raise Error(f"Unexcepted topic_key: {topic_key}, {payload}") 

        if result:
            publish_topic = context["boxes"]["output_topic"]
            context['client'].publish(publish_topic, result)
            logger.info(f"[{box_name}] Result published on '{publish_topic}': {result}")
    except Exception as e:
        logger.error(f"[{box_name}] Error processing '{topic_key}': {e}") 


def process_general_off(box_name, context, payload):
    return "general off"

def process_maintenance_mode(box_name, context, payload):
    return "maintenance mode"

def process_cmd(box_name, context, payload):
    return f"cmd: {payload}"

def process_high_temp(box_name, context, payload):
    return f"high_temp: {payload}"

def process_window(box_name, context, sub_key, payload):
    return f"window: {sub_key}, {payload}"
